@@ -1,4 +1,4 @@
-from collections import Counter, OrderedDict
+from collections import OrderedDict
 try:
     from collections.abc import Mapping
 except ImportError:  # python <3.7
@@ -12,11 +12,9 @@ import requests
 import string
 import sys
 
+import json
 import numpy as np
 import pandas as pd
-
-import nltk
-import nltk.corpus
 import spacy  # noqa
 import configargparse
 from environment import Environment
@@ -62,7 +60,7 @@ DEFAULT_CONFIG = {
     'semantic_score': '.5',
     'debug': True,
     'wiki_title_max_words': 4,
-    'score_weights': '{"spell": .25, "sentiment": .25, "semantic": .5}',
+    'score_weights': '{"spell": .25, "semantic": .5}',
     'qa_model': 'albert-large-v2-0.2.0',
 }
 DEFAULT_CONFIG.update(env.parsed)
@@ -252,13 +250,6 @@ def parse_args(args):
         dest='semantic',
         metavar='FLOAT',
         help='set weight of the semantic quality score')
-    parser.add_argument(
-        '--sentiment',
-        type=float,
-        default=0.5,
-        dest='sentiment',
-        metavar='FLOAT',
-        help='set weight of the sentiment quality score')
     parser.add_argument(
         '--spell',
         type=float,
@@ -361,28 +352,13 @@ LANGS = ['en_core_web_sm', 'en_core_web_md', 'en_core_web_lg']
 LANGS_ABBREV = 'en enmd enlg'.split()
 LANGS += 'de_core_news_sm de_core_news_md de_trf_bertbasecased_lg'.split()
 LANGS_ABBREV += 'de demd delg'.split()
-
-# FOREIGN_LANGS_DF = pd.read_csv(os.path.join(DATA_DIR, 'spacy_languages.csv'))
-# for i, row in FOREIGN_LANGS_DF.iterrows():
-#     match = re.match(r'(\d)+\b', row['Models'])
-#     if match:
-#         num_models = int(match.groups()[0])
-#         LANGS.extend([row['Code']] * num_models)
-
-# tuple('de de de'.split())  # df=pd.read_html('https://spacy.io/usage/models')[0]
 LANGS_ABBREV = dict(zip(LANGS_ABBREV, LANGS))
 
 LANG = getattr(args, 'spacy_lang', None) or DEFAULT_CONFIG.get('spacy_lang') or LANGS[0]
 log.info(f'LANG=spacy_lang={LANG}')
 
-try:
-    STOPWORDS_DICT = Counter(nltk.corpus.stopwords.words('english'))
-except LookupError:
-    log.info('Downloading NLTK stopwords and punkt corpora')
-    nltk.download('stopwords', quiet=True)
-    nltk.download('punkt', quiet=True)
-    STOPWORDS_DICT = Counter(nltk.corpus.stopwords.words('english'))
-STOPWORDS = set(STOPWORDS_DICT)
+STOPWORDS = set(json.load(open(os.path.join(DATA_DIR, 'constants', 'nltk_stopwords_english.json'))))
+STOPWORDS_DICT = dict(zip(STOPWORDS, [1] * len(STOPWORDS)))
 
 QUESTIONWORDS = set('who what when were why which how'.split() + ['how come', 'why does', 'can i', 'can you', 'which way'])
 QUESTION_STOPWORDS = QUESTIONWORDS | STOPWORDS
