@@ -16,8 +16,9 @@ from qary.etl.nesting import dict_merge
 log = logging.getLogger(__name__)
 
 # tuple to hold confidence, text, and bot-name
-BotReply_fields = ['confidence', 'text', 'skill', 'context']
-BotReply = namedtuple('BotReply', BotReply_fields, defaults=[None] * len(BotReply_fields))  # noqa
+BotReply_fields = ('confidence', 'text', 'skill', 'context')
+BotReply = namedtuple('BotReply', BotReply_fields)  # noqa
+BotReply.__new__.__defaults__ = (None,) * len(BotReply_fields)
 
 
 def normalize_replies(replies):
