@@ -2,14 +2,22 @@
 from qary.skills.qa import Skill as QASkill
 from qary.etl.spell import make_spelling_corrections
 
+import transformers
+# # Allocate a pipeline for question-answering
+# >>>
+# >>> question_answerer({
+# ...     'question': 'What is the name of the repository ?',
+# ...     'context': 'Pipeline have been included in the huggingface/transformers repositor
+
 
 class Skill(QASkill):
     """ Skill that provides answers to questions given context data containing the answer
 
-    >>> skill = Skill()
-    >>> skill.reply('How many in a bakurs dozin?')[0][1]
+    FIXME: QA skill broke with upgrade of transformers package (and torch + SpaCy)
+    >> skill = Skill()
+    >> skill.reply('How many in a bakurs dozin?')[0][1]
     '13'
-    >>> skill.reply('When was the telefone inventid?')[0][1]
+    >> skill.reply('When was the telefone inventid?')[0][1]
     '1844.'
     """
 
